Learn R Programming

rugarch (version 1.2-2)

VaRloss: Value at Risk loss function of Gonzalez-Rivera, Lee, and Mishra (2004)

Description

Returns the VaR loss function described in Gonzalez-Rivera, Lee, and Mishra (2004) which is an appropriate function on which to compare models using such methods as the Model Confidence Set (MCS).

Usage

VaRloss(alpha, actual, VaR)

Arguments

alpha
The quantile (coverage) used for the VaR.
actual
A numeric vector of the actual (realized) values.
VaR
The numeric vector of VaR.

References

Gonzalez-Rivera, G., Lee, T. H., and Mishra, S. 2004, Forecasting volatility: A reality check based on option pricing, utility function, value-at-risk, and predictive likelihood. International Journal of Forecasting, 20(4), 629--645.