Usage
arfimadistribution(fitORspec, n.sim = 2000, n.start = 1, m.sim = 100,
recursive = FALSE, recursive.length = 6000, recursive.window = 1000,
prereturns = NA, preresiduals = NA, rseed = NA,
custom.dist = list(name = NA, distfit = NA, type = "z"), mexsimdata = NULL,
fit.control = list(), solver = "solnp", solver.control = list(),
cluster = NULL, ...)
Arguments
fitORspec
Either an ARFIMA fit object of class
ARFIMAfit or alternatively an ARFIMA specification object
of class ARFIMAspec with valid parameters supplied via the
fixed.par
n.sim
The simulation horizon.
n.start
The burn-in sample.
m.sim
The number of simulations.
recursive
Whether to perform a recursive simulation on an expanding
window.
recursive.length
If recursive is TRUE, this indicates the final
length of the simulation horizon, with starting length n.sim.
recursive.window
If recursive is TRUE, this indicates the
increment to the expanding window. Together with recursive.length, it
determines the total number of separate and increasing length windows which will
be simulated and fitted.
prereturns
Allows the starting return data to be provided by the user.
preresiduals
Allows the starting residuals to be provided by the user.
rseed
Optional seeding value(s) for the random number generator.
custom.dist
Optional density with fitted object from which to simulate.
mexsimdata
Matrix of simulated external regressor-in-mean data. If the
fit object contains external regressors in the mean equation, this must be
provided.
solver
One of either nlminb or solnp.
solver.control
Control arguments list passed to optimizer.
fit.control
Control arguments passed to the fitting routine (as in the
arfimafit method).
cluster
A cluster object created by calling makeCluster from the parallel
package. If it is not NULL, then this will be used for parallel estimation.