Usage
arfimafit(spec, data, out.sample = 0, solver = "solnp", solver.control = list(),
fit.control = list(fixed.se = 0, scale = 0), numderiv.control = list(grad.eps=1e-4,
grad.d=0.0001, grad.zero.tol=sqrt(.Machine$double.eps/7e-7), hess.eps=1e-4, hess.d=0.1,
hess.zero.tol=sqrt(.Machine$double.eps/7e-7), r=4, v=2), ...)
Arguments
data
A univariate data object. Can be a numeric vector, matrix,
data.frame, zoo, xts, timeSeries, ts or irts object.
spec
An ARFIMA spec object of class ARFIMAspec.
out.sample
A positive integer indicating the number of periods before
the last to keep for out of sample forecasting (see details).
solver
One of either nlminb, solnp, gosolnp
or nloptr.
solver.control
Control arguments list passed to optimizer.
fit.control
Control arguments passed to the fitting routine. The
fixed.se argument controls whether standard errors should be calculated for
those parameters which were fixed (through the fixed.pars argument of the
arfim numderiv.control
Control arguments passed to the numerical routines for the
calculation of the standard errors. See the documentation in the numDeriv package
for further details. The arguments which start with hess are passed to
the hessian routine whi