Usage
ddist(distribution = "norm", y, mu = 0, sigma = 1, lambda = -0.5, skew = 1,
shape = 5)
pdist(distribution = "norm", q, mu = 0, sigma = 1, lambda = -0.5, skew = 1,
shape = 5)
qdist(distribution = "norm", p, mu = 0, sigma = 1, lambda = -0.5, skew = 1,
shape = 5)
rdist(distribution = "norm", n, mu = 0, sigma = 1, lambda = -0.5, skew = 1,
shape = 5)
fitdist(distribution = "norm", x, control=list())
dskewness(distribution = "norm", skew = 1, shape = 5, lambda = -0.5)
dkurtosis(distribution = "norm", skew = 1, shape = 5, lambda = -0.5)
distplot(distribution = "snorm", skewbounds = NULL, shapebounds = NULL,
n.points = NULL)
skdomain(distribution = "nig", kurt.max = 30, n.points = 25, lambda = 1,
plot = TRUE, legend = NULL)
Arguments
distribution
The distribution name. Valid choices are norm, snorm,
std, sstd, ged, sged, nig,
jsu.
mu, sigma, skew, shape
location, scale and skewness and shape parameters (see details).
lambda
The additional shape parameter for the Generalized Hyperbolic and NIG
distributions.
n
The number of observations.
p
A numeric vector of probabilities.
y, q
A numeric vector of quantiles.
x
A univariate dataset (for fitting routine).
control
Control parameters passed to the solnp solver.
skewbounds
The skewed distribution skew bounds for the plot. Leaving it NULL will use a good set of
defaults for display purposes.
shapebounds
The shaped distribution shape bounds for the plot. Leaving it NULL will use a good set of
defaults for display purposes.
n.points
The number of points between the lower and upper bounds of the skew and shape
parameters for which to evaluate the skewness and excess kurtosis. For the
skdomain function this determines the kurtosis interval (3-max.kurt) for which
to determine (using
kurt.max
The maximum kurtosis for which to determine the bounds for the skewness-kurtosis
domain.
plot
Whether to plot the results.
legend
Whether to include a legend with the plot in the skdomain.