Learn R Programming

rugarch (version 1.2-2)

arfimafit-methods: function: ARFIMA Fit

Description

Method for fitting an ARFIMA models.

Usage

arfimafit(spec, data, out.sample = 0, solver = "solnp", solver.control = list(), 
fit.control = list(fixed.se = 0, scale = 0), ...)

Arguments

data
A univariate data object. Can be a numeric vector, matrix, data.frame, zoo, xts, timeSeries, ts or irts object.
spec
An ARFIMA spec object of class ARFIMAspec.
out.sample
A positive integer indicating the number of periods before the last to keep for out of sample forecasting (see details).
solver
One of either nlminb, solnp, gosolnp or nloptr.
solver.control
Control arguments list passed to optimizer.
fit.control
Control arguments passed to the fitting routine. The fixed.se argument controls whether standard errors should be calculated for those parameters which were fixed (through the fixed.pars argument of the arfim
...
.

Value

  • A ARFIMAfit object containing details of the ARFIMA fit.

Details

The ARFIMA optimization routine first calculates a set of feasible starting points which are used to initiate the ARFIMA Maximum Likelihood recursion. The main part of the likelihood calculation is performed in C-code for speed. The out.sample option is provided in order to carry out forecast performance testing against actual data. A minimum of 5 data points are required for these tests. If the out.sample option is positive, then the routine will fit only N - out.sample (where N is the total data length) data points, leaving out.sample points for forecasting and testing using the forecast performance measures. In the arfimaforecast routine the n.ahead may also be greater than the out.sample number resulting in a combination of out of sample data points matched against actual data and some without, which the forecast performance tests will ignore. The gosolnp solver allows for the initialization of multiple restarts of the solnp solver with randomly generated parameters (see documentation in the Rsolnp-package for details of the strategy used). The solver.control list then accepts the following additional (to the solnp) arguments: n.restarts is the number of solver restarts required (defaults to 1), parallel (logical), pkg (either snowfall or multicore) and cores (the number of cores or workers to use) for use of parallel functionality, rseed is the seed to initialize the random number generator, and n.sim is the number of simulated parameter vectors to generate per n.restarts.